#ifndef NT2_INCLUDE_CONSTANTS_PIX_2_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_PIX_2_HPP_INCLUDED

#include <nt2/trigonometric/include/constants/pix_2.hpp>

#endif
